@@ -8,8 +8,8 @@ use deno_core::error::bad_resource_id;
 use deno_core::error::custom_error;
 use deno_core::error::type_error;
 use deno_core::error::AnyError;
-use deno_core::op_async;
-use deno_core::op_sync;
+use deno_core::op;
+
 use deno_core::Extension;
 use deno_core::OpState;
 use deno_core::RcRef;
@@ -38,59 +38,59 @@ use deno_core::error::not_supported;
 pub fn init() -> Extension {
   Extension::builder()
     .ops(vec![
-      ("op_open_sync", op_sync(op_open_sync)),
-      ("op_open_async", op_async(op_open_async)),
-      ("op_seek_sync", op_sync(op_seek_sync)),
-      ("op_seek_async", op_async(op_seek_async)),
-      ("op_fdatasync_sync", op_sync(op_fdatasync_sync)),
-      ("op_fdatasync_async", op_async(op_fdatasync_async)),
-      ("op_fsync_sync", op_sync(op_fsync_sync)),
-      ("op_fsync_async", op_async(op_fsync_async)),
-      ("op_fstat_sync", op_sync(op_fstat_sync)),
-      ("op_fstat_async", op_async(op_fstat_async)),
-      ("op_flock_sync", op_sync(op_flock_sync)),
-      ("op_flock_async", op_async(op_flock_async)),
-      ("op_funlock_sync", op_sync(op_funlock_sync)),
-      ("op_funlock_async", op_async(op_funlock_async)),
-      ("op_umask", op_sync(op_umask)),
-      ("op_chdir", op_sync(op_chdir)),
-      ("op_mkdir_sync", op_sync(op_mkdir_sync)),
-      ("op_mkdir_async", op_async(op_mkdir_async)),
-      ("op_chmod_sync", op_sync(op_chmod_sync)),
-      ("op_chmod_async", op_async(op_chmod_async)),
-      ("op_chown_sync", op_sync(op_chown_sync)),
-      ("op_chown_async", op_async(op_chown_async)),
-      ("op_remove_sync", op_sync(op_remove_sync)),
-      ("op_remove_async", op_async(op_remove_async)),
-      ("op_copy_file_sync", op_sync(op_copy_file_sync)),
-      ("op_copy_file_async", op_async(op_copy_file_async)),
-      ("op_stat_sync", op_sync(op_stat_sync)),
-      ("op_stat_async", op_async(op_stat_async)),
-      ("op_realpath_sync", op_sync(op_realpath_sync)),
-      ("op_realpath_async", op_async(op_realpath_async)),
-      ("op_read_dir_sync", op_sync(op_read_dir_sync)),
-      ("op_read_dir_async", op_async(op_read_dir_async)),
-      ("op_rename_sync", op_sync(op_rename_sync)),
-      ("op_rename_async", op_async(op_rename_async)),
-      ("op_link_sync", op_sync(op_link_sync)),
-      ("op_link_async", op_async(op_link_async)),
-      ("op_symlink_sync", op_sync(op_symlink_sync)),
-      ("op_symlink_async", op_async(op_symlink_async)),
-      ("op_read_link_sync", op_sync(op_read_link_sync)),
-      ("op_read_link_async", op_async(op_read_link_async)),
-      ("op_ftruncate_sync", op_sync(op_ftruncate_sync)),
-      ("op_ftruncate_async", op_async(op_ftruncate_async)),
-      ("op_truncate_sync", op_sync(op_truncate_sync)),
-      ("op_truncate_async", op_async(op_truncate_async)),
-      ("op_make_temp_dir_sync", op_sync(op_make_temp_dir_sync)),
-      ("op_make_temp_dir_async", op_async(op_make_temp_dir_async)),
-      ("op_make_temp_file_sync", op_sync(op_make_temp_file_sync)),
-      ("op_make_temp_file_async", op_async(op_make_temp_file_async)),
-      ("op_cwd", op_sync(op_cwd)),
-      ("op_futime_sync", op_sync(op_futime_sync)),
-      ("op_futime_async", op_async(op_futime_async)),
-      ("op_utime_sync", op_sync(op_utime_sync)),
-      ("op_utime_async", op_async(op_utime_async)),
+      op_open_sync::decl(),
+      op_open_async::decl(),
+      op_seek_sync::decl(),
+      op_seek_async::decl(),
+      op_fdatasync_sync::decl(),
+      op_fdatasync_async::decl(),
+      op_fsync_sync::decl(),
+      op_fsync_async::decl(),
+      op_fstat_sync::decl(),
+      op_fstat_async::decl(),
+      op_flock_sync::decl(),
+      op_flock_async::decl(),
+      op_funlock_sync::decl(),
+      op_funlock_async::decl(),
+      op_umask::decl(),
+      op_chdir::decl(),
+      op_mkdir_sync::decl(),
+      op_mkdir_async::decl(),
+      op_chmod_sync::decl(),
+      op_chmod_async::decl(),
+      op_chown_sync::decl(),
+      op_chown_async::decl(),
+      op_remove_sync::decl(),
+      op_remove_async::decl(),
+      op_copy_file_sync::decl(),
+      op_copy_file_async::decl(),
+      op_stat_sync::decl(),
+      op_stat_async::decl(),
+      op_realpath_sync::decl(),
+      op_realpath_async::decl(),
+      op_read_dir_sync::decl(),
+      op_read_dir_async::decl(),
+      op_rename_sync::decl(),
+      op_rename_async::decl(),
+      op_link_sync::decl(),
+      op_link_async::decl(),
+      op_symlink_sync::decl(),
+      op_symlink_async::decl(),
+      op_read_link_sync::decl(),
+      op_read_link_async::decl(),
+      op_ftruncate_sync::decl(),
+      op_ftruncate_async::decl(),
+      op_truncate_sync::decl(),
+      op_truncate_async::decl(),
+      op_make_temp_dir_sync::decl(),
+      op_make_temp_dir_async::decl(),
+      op_make_temp_file_sync::decl(),
+      op_make_temp_file_async::decl(),
+      op_cwd::decl(),
+      op_futime_sync::decl(),
+      op_futime_async::decl(),
+      op_utime_sync::decl(),
+      op_utime_async::decl(),
     ])
     .build()
 }
@@ -157,10 +157,10 @@ fn open_helper(
   Ok((path, open_options))
 }
 
+#[op]
 fn op_open_sync(
   state: &mut OpState,
   args: OpenArgs,
-  _: (),
 ) -> Result<ResourceId, AnyError> {
   let (path, open_options) = open_helper(state, args)?;
   let std_file = open_options.open(&path).map_err(|err| {
@@ -172,10 +172,10 @@ fn op_open_sync(
   Ok(rid)
 }
 
+#[op]
 async fn op_open_async(
   state: Rc<RefCell<OpState>>,
   args: OpenArgs,
-  _: (),
 ) -> Result<ResourceId, AnyError> {
   let (path, open_options) = open_helper(&mut state.borrow_mut(), args)?;
   let tokio_file = tokio::fs::OpenOptions::from(open_options)
@@ -214,11 +214,8 @@ fn seek_helper(args: SeekArgs) -> Result<(u32, SeekFrom), AnyError> {
   Ok((rid, seek_from))
 }
 
-fn op_seek_sync(
-  state: &mut OpState,
-  args: SeekArgs,
-  _: (),
-) -> Result<u64, AnyError> {
+#[op]
+fn op_seek_sync(state: &mut OpState, args: SeekArgs) -> Result<u64, AnyError> {
   let (rid, seek_from) = seek_helper(args)?;
   let pos = StdFileResource::with(state, rid, |r| match r {
     Ok(std_file) => std_file.seek(seek_from).map_err(AnyError::from),
@@ -229,10 +226,10 @@ fn op_seek_sync(
   Ok(pos)
 }
 
+#[op]
 async fn op_seek_async(
   state: Rc<RefCell<OpState>>,
   args: SeekArgs,
-  _: (),
 ) -> Result<u64, AnyError> {
   let (rid, seek_from) = seek_helper(args)?;
 
@@ -253,10 +250,10 @@ async fn op_seek_async(
   Ok(pos)
 }
 
+#[op]
 fn op_fdatasync_sync(
   state: &mut OpState,
   rid: ResourceId,
-  _: (),
 ) -> Result<(), AnyError> {
   StdFileResource::with(state, rid, |r| match r {
     Ok(std_file) => std_file.sync_data().map_err(AnyError::from),
@@ -265,10 +262,10 @@ fn op_fdatasync_sync(
   Ok(())
 }
 
+#[op]
 async fn op_fdatasync_async(
   state: Rc<RefCell<OpState>>,
   rid: ResourceId,
-  _: (),
 ) -> Result<(), AnyError> {
   let resource = state
     .borrow_mut()
@@ -287,11 +284,8 @@ async fn op_fdatasync_async(
   Ok(())
 }
 
-fn op_fsync_sync(
-  state: &mut OpState,
-  rid: ResourceId,
-  _: (),
-) -> Result<(), AnyError> {
+#[op]
+fn op_fsync_sync(state: &mut OpState, rid: ResourceId) -> Result<(), AnyError> {
   StdFileResource::with(state, rid, |r| match r {
     Ok(std_file) => std_file.sync_all().map_err(AnyError::from),
     Err(_) => Err(type_error("cannot sync this type of resource".to_string())),
@@ -299,10 +293,10 @@ fn op_fsync_sync(
   Ok(())
 }
 
+#[op]
 async fn op_fsync_async(
   state: Rc<RefCell<OpState>>,
   rid: ResourceId,
-  _: (),
 ) -> Result<(), AnyError> {
   let resource = state
     .borrow_mut()
@@ -321,10 +315,10 @@ async fn op_fsync_async(
   Ok(())
 }
 
+#[op]
 fn op_fstat_sync(
   state: &mut OpState,
   rid: ResourceId,
-  _: (),
 ) -> Result<FsStat, AnyError> {
   let metadata = StdFileResource::with(state, rid, |r| match r {
     Ok(std_file) => std_file.metadata().map_err(AnyError::from),
@@ -333,10 +327,10 @@ fn op_fstat_sync(
   Ok(get_stat(metadata))
 }
 
+#[op]
 async fn op_fstat_async(
   state: Rc<RefCell<OpState>>,
   rid: ResourceId,
-  _: (),
 ) -> Result<FsStat, AnyError> {
   let resource = state
     .borrow_mut()
@@ -355,6 +349,7 @@ async fn op_fstat_async(
   Ok(get_stat(metadata))
 }
 
+#[op]
 fn op_flock_sync(
   state: &mut OpState,
   rid: ResourceId,
@@ -376,6 +371,7 @@ fn op_flock_sync(
   })
 }
 
+#[op]
 async fn op_flock_async(
   state: Rc<RefCell<OpState>>,
   rid: ResourceId,
@@ -416,10 +412,10 @@ async fn op_flock_async(
   .await?
 }
 
+#[op]
 fn op_funlock_sync(
   state: &mut OpState,
   rid: ResourceId,
-  _: (),
 ) -> Result<(), AnyError> {
   use fs3::FileExt;
   super::check_unstable(state, "Deno.funlockSync");
@@ -433,10 +429,10 @@ fn op_funlock_sync(
   })
 }
 
+#[op]
 async fn op_funlock_async(
   state: Rc<RefCell<OpState>>,
   rid: ResourceId,
-  _: (),
 ) -> Result<(), AnyError> {
   use fs3::FileExt;
   super::check_unstable2(&state, "Deno.funlock");
@@ -469,11 +465,8 @@ async fn op_funlock_async(
   .await?
 }
 
-fn op_umask(
-  state: &mut OpState,
-  mask: Option<u32>,
-  _: (),
-) -> Result<u32, AnyError> {
+#[op]
+fn op_umask(state: &mut OpState, mask: Option<u32>) -> Result<u32, AnyError> {
   super::check_unstable(state, "Deno.umask");
   // TODO implement umask for Windows
   // see https://github.com/nodejs/node/blob/master/src/node_process_methods.cc
@@ -501,11 +494,8 @@ fn op_umask(
   }
 }
 
-fn op_chdir(
-  state: &mut OpState,
-  directory: String,
-  _: (),
-) -> Result<(), AnyError> {
+#[op]
+fn op_chdir(state: &mut OpState, directory: String) -> Result<(), AnyError> {
   let d = PathBuf::from(&directory);
   state.borrow_mut::<Permissions>().read.check(&d)?;
   set_current_dir(&d).map_err(|err| {
@@ -522,11 +512,8 @@ pub struct MkdirArgs {
   mode: Option<u32>,
 }
 
-fn op_mkdir_sync(
-  state: &mut OpState,
-  args: MkdirArgs,
-  _: (),
-) -> Result<(), AnyError> {
+#[op]
+fn op_mkdir_sync(state: &mut OpState, args: MkdirArgs) -> Result<(), AnyError> {
   let path = Path::new(&args.path).to_path_buf();
   let mode = args.mode.unwrap_or(0o777) & 0o777;
   state.borrow_mut::<Permissions>().write.check(&path)?;
@@ -544,10 +531,10 @@ fn op_mkdir_sync(
   Ok(())
 }
 
+#[op]
 async fn op_mkdir_async(
   state: Rc<RefCell<OpState>>,
   args: MkdirArgs,
-  _: (),
 ) -> Result<(), AnyError> {
   let path = Path::new(&args.path).to_path_buf();
   let mode = args.mode.unwrap_or(0o777) & 0o777;
@@ -582,11 +569,8 @@ pub struct ChmodArgs {
   mode: u32,
 }
 
-fn op_chmod_sync(
-  state: &mut OpState,
-  args: ChmodArgs,
-  _: (),
-) -> Result<(), AnyError> {
+#[op]
+fn op_chmod_sync(state: &mut OpState, args: ChmodArgs) -> Result<(), AnyError> {
   let path = Path::new(&args.path).to_path_buf();
   let mode = args.mode & 0o777;
   let err_mapper = |err: Error| {
@@ -611,10 +595,10 @@ fn op_chmod_sync(
   }
 }
 
+#[op]
 async fn op_chmod_async(
   state: Rc<RefCell<OpState>>,
   args: ChmodArgs,
-  _: (),
 ) -> Result<(), AnyError> {
   let path = Path::new(&args.path).to_path_buf();
   let mode = args.mode & 0o777;
@@ -656,11 +640,8 @@ pub struct ChownArgs {
   gid: Option<u32>,
 }
 
-fn op_chown_sync(
-  state: &mut OpState,
-  args: ChownArgs,
-  _: (),
-) -> Result<(), AnyError> {
+#[op]
+fn op_chown_sync(state: &mut OpState, args: ChownArgs) -> Result<(), AnyError> {
   let path = Path::new(&args.path).to_path_buf();
   state.borrow_mut::<Permissions>().write.check(&path)?;
   debug!(
@@ -690,10 +671,10 @@ fn op_chown_sync(
   }
 }
 
+#[op]
 async fn op_chown_async(
   state: Rc<RefCell<OpState>>,
   args: ChownArgs,
-  _: (),
 ) -> Result<(), AnyError> {
   let path = Path::new(&args.path).to_path_buf();
 
@@ -738,10 +719,10 @@ pub struct RemoveArgs {
   recursive: bool,
 }
 
+#[op]
 fn op_remove_sync(
   state: &mut OpState,
   args: RemoveArgs,
-  _: (),
 ) -> Result<(), AnyError> {
   let path = PathBuf::from(&args.path);
   let recursive = args.recursive;
@@ -783,10 +764,10 @@ fn op_remove_sync(
   Ok(())
 }
 
+#[op]
 async fn op_remove_async(
   state: Rc<RefCell<OpState>>,
   args: RemoveArgs,
-  _: (),
 ) -> Result<(), AnyError> {
   let path = PathBuf::from(&args.path);
   let recursive = args.recursive;
@@ -841,10 +822,10 @@ pub struct CopyFileArgs {
   to: String,
 }
 
+#[op]
 fn op_copy_file_sync(
   state: &mut OpState,
   args: CopyFileArgs,
-  _: (),
 ) -> Result<(), AnyError> {
   let from = PathBuf::from(&args.from);
   let to = PathBuf::from(&args.to);
@@ -879,10 +860,10 @@ fn op_copy_file_sync(
   Ok(())
 }
 
+#[op]
 async fn op_copy_file_async(
   state: Rc<RefCell<OpState>>,
   args: CopyFileArgs,
-  _: (),
 ) -> Result<(), AnyError> {
   let from = PathBuf::from(&args.from);
   let to = PathBuf::from(&args.to);
@@ -1007,10 +988,10 @@ pub struct StatArgs {
   lstat: bool,
 }
 
+#[op]
 fn op_stat_sync(
   state: &mut OpState,
   args: StatArgs,
-  _: (),
 ) -> Result<FsStat, AnyError> {
   let path = PathBuf::from(&args.path);
   let lstat = args.lstat;
@@ -1027,10 +1008,10 @@ fn op_stat_sync(
   Ok(get_stat(metadata))
 }
 
+#[op]
 async fn op_stat_async(
   state: Rc<RefCell<OpState>>,
   args: StatArgs,
-  _: (),
 ) -> Result<FsStat, AnyError> {
   let path = PathBuf::from(&args.path);
   let lstat = args.lstat;
@@ -1056,10 +1037,10 @@ async fn op_stat_async(
   .unwrap()
 }
 
+#[op]
 fn op_realpath_sync(
   state: &mut OpState,
   path: String,
-  _: (),
 ) -> Result<String, AnyError> {
   let path = PathBuf::from(&path);
 
@@ -1077,10 +1058,10 @@ fn op_realpath_sync(
   Ok(realpath_str)
 }
 
+#[op]
 async fn op_realpath_async(
   state: Rc<RefCell<OpState>>,
   path: String,
-  _: (),
 ) -> Result<String, AnyError> {
   let path = PathBuf::from(&path);
 
@@ -1114,10 +1095,10 @@ pub struct DirEntry {
   is_symlink: bool,
 }
 
+#[op]
 fn op_read_dir_sync(
   state: &mut OpState,
   path: String,
-  _: (),
 ) -> Result<Vec<DirEntry>, AnyError> {
   let path = PathBuf::from(&path);
 
@@ -1154,10 +1135,10 @@ fn op_read_dir_sync(
   Ok(entries)
 }
 
+#[op]
 async fn op_read_dir_async(
   state: Rc<RefCell<OpState>>,
   path: String,
-  _: (),
 ) -> Result<Vec<DirEntry>, AnyError> {
   let path = PathBuf::from(&path);
   {
@@ -1206,10 +1187,10 @@ pub struct RenameArgs {
   newpath: String,
 }
 
+#[op]
 fn op_rename_sync(
   state: &mut OpState,
   args: RenameArgs,
-  _: (),
 ) -> Result<(), AnyError> {
   let oldpath = PathBuf::from(&args.oldpath);
   let newpath = PathBuf::from(&args.newpath);
@@ -1234,10 +1215,10 @@ fn op_rename_sync(
   Ok(())
 }
 
+#[op]
 async fn op_rename_async(
   state: Rc<RefCell<OpState>>,
   args: RenameArgs,
-  _: (),
 ) -> Result<(), AnyError> {
   let oldpath = PathBuf::from(&args.oldpath);
   let newpath = PathBuf::from(&args.newpath);
@@ -1279,11 +1260,8 @@ pub struct LinkArgs {
   newpath: String,
 }
 
-fn op_link_sync(
-  state: &mut OpState,
-  args: LinkArgs,
-  _: (),
-) -> Result<(), AnyError> {
+#[op]
+fn op_link_sync(state: &mut OpState, args: LinkArgs) -> Result<(), AnyError> {
   let oldpath = PathBuf::from(&args.oldpath);
   let newpath = PathBuf::from(&args.newpath);
 
@@ -1309,10 +1287,10 @@ fn op_link_sync(
   Ok(())
 }
 
+#[op]
 async fn op_link_async(
   state: Rc<RefCell<OpState>>,
   args: LinkArgs,
-  _: (),
 ) -> Result<(), AnyError> {
   let oldpath = PathBuf::from(&args.oldpath);
   let newpath = PathBuf::from(&args.newpath);
@@ -1362,10 +1340,10 @@ pub struct SymlinkOptions {
   _type: String,
 }
 
+#[op]
 fn op_symlink_sync(
   state: &mut OpState,
   args: SymlinkArgs,
-  _: (),
 ) -> Result<(), AnyError> {
   let oldpath = PathBuf::from(&args.oldpath);
   let newpath = PathBuf::from(&args.newpath);
@@ -1423,10 +1401,10 @@ fn op_symlink_sync(
   }
 }
 
+#[op]
 async fn op_symlink_async(
   state: Rc<RefCell<OpState>>,
   args: SymlinkArgs,
-  _: (),
 ) -> Result<(), AnyError> {
   let oldpath = PathBuf::from(&args.oldpath);
   let newpath = PathBuf::from(&args.newpath);
@@ -1487,10 +1465,10 @@ async fn op_symlink_async(
   .unwrap()
 }
 
+#[op]
 fn op_read_link_sync(
   state: &mut OpState,
   path: String,
-  _: (),
 ) -> Result<String, AnyError> {
   let path = PathBuf::from(&path);
 
@@ -1510,10 +1488,10 @@ fn op_read_link_sync(
   Ok(targetstr)
 }
 
+#[op]
 async fn op_read_link_async(
   state: Rc<RefCell<OpState>>,
   path: String,
-  _: (),
 ) -> Result<String, AnyError> {
   let path = PathBuf::from(&path);
   {
@@ -1545,10 +1523,10 @@ pub struct FtruncateArgs {
   len: i32,
 }
 
+#[op]
 fn op_ftruncate_sync(
   state: &mut OpState,
   args: FtruncateArgs,
-  _: (),
 ) -> Result<(), AnyError> {
   let rid = args.rid;
   let len = args.len as u64;
@@ -1559,10 +1537,10 @@ fn op_ftruncate_sync(
   Ok(())
 }
 
+#[op]
 async fn op_ftruncate_async(
   state: Rc<RefCell<OpState>>,
   args: FtruncateArgs,
-  _: (),
 ) -> Result<(), AnyError> {
   let rid = args.rid;
   let len = args.len as u64;
@@ -1591,10 +1569,10 @@ pub struct TruncateArgs {
   len: u64,
 }
 
+#[op]
 fn op_truncate_sync(
   state: &mut OpState,
   args: TruncateArgs,
-  _: (),
 ) -> Result<(), AnyError> {
   let path = PathBuf::from(&args.path);
   let len = args.len;
@@ -1616,10 +1594,10 @@ fn op_truncate_sync(
   Ok(())
 }
 
+#[op]
 async fn op_truncate_async(
   state: Rc<RefCell<OpState>>,
   args: TruncateArgs,
-  _: (),
 ) -> Result<(), AnyError> {
   let path = PathBuf::from(&args.path);
   let len = args.len;
@@ -1699,10 +1677,10 @@ pub struct MakeTempArgs {
   suffix: Option<String>,
 }
 
+#[op]
 fn op_make_temp_dir_sync(
   state: &mut OpState,
   args: MakeTempArgs,
-  _: (),
 ) -> Result<String, AnyError> {
   let dir = args.dir.map(|s| PathBuf::from(&s));
   let prefix = args.prefix.map(String::from);
@@ -1728,10 +1706,10 @@ fn op_make_temp_dir_sync(
   Ok(path_str)
 }
 
+#[op]
 async fn op_make_temp_dir_async(
   state: Rc<RefCell<OpState>>,
   args: MakeTempArgs,
-  _: (),
 ) -> Result<String, AnyError> {
   let dir = args.dir.map(|s| PathBuf::from(&s));
   let prefix = args.prefix.map(String::from);
@@ -1762,10 +1740,10 @@ async fn op_make_temp_dir_async(
   .unwrap()
 }
 
+#[op]
 fn op_make_temp_file_sync(
   state: &mut OpState,
   args: MakeTempArgs,
-  _: (),
 ) -> Result<String, AnyError> {
   let dir = args.dir.map(|s| PathBuf::from(&s));
   let prefix = args.prefix.map(String::from);
@@ -1791,10 +1769,10 @@ fn op_make_temp_file_sync(
   Ok(path_str)
 }
 
+#[op]
 async fn op_make_temp_file_async(
   state: Rc<RefCell<OpState>>,
   args: MakeTempArgs,
-  _: (),
 ) -> Result<String, AnyError> {
   let dir = args.dir.map(|s| PathBuf::from(&s));
   let prefix = args.prefix.map(String::from);
@@ -1833,10 +1811,10 @@ pub struct FutimeArgs {
   mtime: (i64, u32),
 }
 
+#[op]
 fn op_futime_sync(
   state: &mut OpState,
   args: FutimeArgs,
-  _: (),
 ) -> Result<(), AnyError> {
   super::check_unstable(state, "Deno.futimeSync");
   let rid = args.rid;
@@ -1856,10 +1834,10 @@ fn op_futime_sync(
   Ok(())
 }
 
+#[op]
 async fn op_futime_async(
   state: Rc<RefCell<OpState>>,
   args: FutimeArgs,
-  _: (),
 ) -> Result<(), AnyError> {
   super::check_unstable2(&state, "Deno.futime");
   let rid = args.rid;
@@ -1904,11 +1882,8 @@ pub struct UtimeArgs {
   mtime: (i64, u32),
 }
 
-fn op_utime_sync(
-  state: &mut OpState,
-  args: UtimeArgs,
-  _: (),
-) -> Result<(), AnyError> {
+#[op]
+fn op_utime_sync(state: &mut OpState, args: UtimeArgs) -> Result<(), AnyError> {
   super::check_unstable(state, "Deno.utime");
 
   let path = PathBuf::from(&args.path);
@@ -1922,10 +1897,10 @@ fn op_utime_sync(
   Ok(())
 }
 
+#[op]
 async fn op_utime_async(
   state: Rc<RefCell<OpState>>,
   args: UtimeArgs,
-  _: (),
 ) -> Result<(), AnyError> {
   super::check_unstable(&state.borrow(), "Deno.utime");
 
@@ -1949,7 +1924,8 @@ async fn op_utime_async(
   .unwrap()
 }
 
-fn op_cwd(state: &mut OpState, _: (), _: ()) -> Result<String, AnyError> {
+#[op]
+fn op_cwd(state: &mut OpState) -> Result<String, AnyError> {
   let path = current_dir()?;
   state
     .borrow_mut::<Permissions>()
