@@ -15,6 +15,7 @@ pub struct BootstrapOptions {
   pub location: Option<ModuleSpecifier>,
   /// Sets `Deno.noColor` in JS runtime.
   pub no_color: bool,
+  pub is_tty: bool,
   /// Sets `Deno.version.deno` in JS runtime.
   pub runtime_version: String,
   /// Sets `Deno.version.typescript` in JS runtime.
@@ -33,6 +34,7 @@ impl BootstrapOptions {
       "denoVersion": self.runtime_version,
       "location": self.location,
       "noColor": self.no_color,
+      "isTty": self.is_tty,
       "tsVersion": self.ts_version,
       "unstableFlag": self.unstable,
       // Web worker only
